@@ -91,6 +91,8 @@ func NamespacePackageNamersForLanguage(l syftPkg.Language) map[string]NamerByPac
 		namespaces["github:npm"] = defaultPackageNamer
 	case syftPkg.Python:
 		namespaces["github:python"] = defaultPackageNamer
+	case syftPkg.Dotnet:
+		namespaces["github:nuget"] = defaultPackageNamer
 	default:
 		namespaces[fmt.Sprintf("github:%s", l)] = defaultPackageNamer
 	}
